<?php

namespace Netim {
	$countryCodeToRegex = array(
		'AD' => 'AD|AND|andorr[ae]',
		'AE' => 'AE|ARE|UAE|united arab emirates|emirats arabes unis',
		'AF' => 'AF|AFG|afghanistan',
		'AG' => 'AG|ATG|antigua|barbuda|antigua (and|et) barbuda',
		'AI' => 'AI|AIA|anguilla',
		'AL' => 'AL|ALB|albani[ae]',
		'AM' => 'AM|armenia|armenie',
		'AO' => 'AO|AGO|angola',
		'AQ' => 'AQ|ATA|antarcti(ca|que)',
		'AR' => 'AR|ARG|argentin[ae]',
		'AS' => 'AS|ASM|american samoa|samoa americaines',
		'AT' => 'AT|AUT|austria|autriche',
		'AU' => 'AU|AUS|australi[ae]',
		'AW' => 'AW|ABW|aruba',
		'AX' => 'AX|ALA|aland islands|((les )?iles )?aland',
		'AZ' => 'AZ|AZE|azerbai(d?j)an',
		'BA' => 'BA|BIH|bosnia|bosnia and herzegovina|bosnie|bosnie herzegovine',
		'BB' => 'BB|BRB|barbad(os|e)',
		'BD' => 'BD|BGD|bangladesh',
		'BE' => 'BE|BEL|belgi(um|que)',
		'BF' => 'BF|BFA|burkina faso',
		'BG' => 'BG|BGR|bulgari[ae]',
		'BH' => 'BH|BHR|bahr[ae]in',
		'BI' => 'BI|BDI|burundi',
		'BJ' => 'BJ|BEN|benin',
		'BL' => 'BL|BLM|saint barthelemy',
		'BM' => 'BM|BMU|bermud(a|es)',
		'BN' => 'BN|BRN|brunei',
		'BO' => 'BO|BOL|bolivi[ea]',
		'BQ' => 'BQ|BES|bonaire sint eustatius and saba|bonaire saint eustache et saba',
		'BR' => 'BR|BRA|brazil|bresil',
		'BS' => 'BS|BHS|bahamas',
		'BT' => 'BT|BTN|bho?utan',
		'BV' => "BV|BVT|bouvet island|((l')?ile )?bouvet",
		'BW' => 'BW|BWA|botswana',
		'BY' => 'BY|BLR|belarus|bielorussie',
		'BZ' => 'BZ|BLZ|belize',
		'CA' => 'CA|CAN|canada',
		'CC'  => "CC|CCK|cocos (\(keeling\) |keeling )?island|((l')?iles )?cocos( \(keeling\)| keeling)?",
		'CD' => 'CD|COD|(the )?democratic republic (of )?(the )?congo|(la )?republique democratique (du )?congo',
		'CF' => 'CF|CAF|central african republic|republique centrafricaine',
		'CG' => 'CG|COG|congo',
		'CH' => 'CH|CHE|switzerland|suisse',
		'CI' => "CI|CIV|ivory coast|cote d'ivoire",
		'CK' => 'CK|COK|cook|cook islands|((les )?iles )?cook',
		'CL' => 'CL|CHL|chil[ei]',
		'CM' => 'CM|CMR|camero[ou]n',
		'CN' => 'CN|CHN|chin[ae]',
		'CO' => 'CO|COL|colombi[ae]',
		'CR' => 'CR|CRI|costa rica',
		'CU' => 'CU|CUB|cuba',
		'CV' => 'CV|CPV|cabo verde',
		'CW' => 'CW|CUW|curacao',
		'CX' => "CX|CXR|christmas island|((l')?ile )?christmas",
		'CY' => 'CY|CYP|cyprus|chypre',
		'CZ' => 'CZ|CZE|czechia|tchequie|republique tcheque',
		'DE' => 'DE|DEU|germany|allemagne',
		'DJ' => 'DJ|DJI|djibouti',
		'DK' => 'DK|DNK|denmark|danemark',
		'DM' => 'DM|DMA|domini(ca|que)',
		'DO' => 'DO|DOM|dominican republic|((la )?republique )?dominicaine',
		'DZ' => 'DZ|DZA|algeri[ae]',
		'EC' => 'EC|ECU|ecuador|equateur',
		'EE' => 'EE|EST|estoni[ae]',
		'EG' => 'EG|EGY|egypte?',
		'EH' => 'EH|ESH|western sahara|(le )?sahara occidental',
		'ER' => "ER|ERI|eritrea|(l')?erythree",
		'ES' => 'ES|ESP|spain|espagne',
		'ET' => 'ET|ETH|ethiopi[ae]',
		'FI' => 'FI|FIN|finlande?',
		'FJ' => 'FJ|FJI|fid?ji',
		'FK' => 'FK|FLK|(the )?falkland islands|(the )?malvinas|((les )?iles )?(falkland|malouines)',
		'FM' => 'FM|FSM|((federated )?states of )?micronesia|(etats (federes )?de )?micronesie',
		'FO' => 'FO|FRO|(the )?faroe islands|((les )?iles )?feroe',
		'FR' => 'FR|FRA|france',
		'GA' => 'GA|GAB|gabon',
		'GB' =>  "GB|GBR|(the )?united kingdom|great britain|northern ireland|(the )?united kingdom of great britain|(the )?united kingdom of great britain and northern ireland|great britain and northern ireland|(le )?royaume uni|(de )?grande bretagne|(et (d')?)?irlande du nord|(le )?royaume uni de grande bretagne|(le )?royaume uni de grande bretagne (et (d')?)?irlande du nord|grande bretagne (et (d')?)?irlande du nord",
		'GD' => 'GD|GRD|grenad[ae]',
		'GE' => 'GE|GEO|georgi[ae]',
		'GF' => 'GF|GUF|french guiana|(la )?guyane francaise',
		'GG' => 'GG|GGY|guerne?sey',
		'GH' => 'GH|GHA|ghana',
		'GI' => 'GI|GIB|gibraltar',
		'GL' => 'GL|GRL|greenland|groenland',
		'GM' => 'GM|GMB|gambi[ae]',
		'GN' => 'GN|GIN|guine[ae]',
		'GP' => 'GP|GLP|guadeloupe',
		'GQ' => 'GQ|GNQ|equatorial guinea|guinee equatoriale',
		'GR' => 'GR|GRC|gre?ece',
		'GS' => 'GS|SGS|(south georgia and the |the )?south sandwich islands|(georgie du sud et les |les )?iles sandwich du sud',
		'GT' => 'GT|GTM|guatemala',
		'GU' => 'GU|GUM|guam',
		'GW' => 'GW|GNB|guine[ae] bissau',
		'GY' => 'GY|GUY|guyana',
		'HK' => 'HK|HKG|hong kong',
		'HM' =>  "HM|HMD|(heard (island )?and mcdonald islands|heard island|mcdonald islands)|(l')?ile (heard|macdonald|heard et macdonald)",
		'HN' => 'HN|HND|honduras',
		'HR' => 'HR|HRV|croati[ea]',
		'HT' => 'HT|HTI|haiti',
		'HU' => 'HU|HUN|hungary|hongrie',
		'ID' => 'ID|IDN|indonesi[ae]',
		'IE' => 'IE|IRL|ireland|irlande',
		'IL' => 'IL|ISR|israel',
		'IM' => 'IM|IMN|isle of man|ile de man',
		'IN' => 'IN|IND|ind(ia|e)',
		'IO' => "IO|IOT|(the )?british indian (ocean )?territory|(le )?territoire britannique (de l'ocean )?indien",
		'IQ' => 'IQ|IRQ|ira[qk]',
		'IR' => "IR|IRN|iran|islamic republic( of)? iran|republique islamique (d')?iran",
		'IS' => "IS|ISL|iceland|(l')?islande",
		'IT' => "IT|ITA|italy|(l')?italie",
		'JE' => 'JE|JEY|jersey',
		'JM' => 'JM|JAM|jamaica|jamaique',
		'JO' => 'JO|JOR|jordan(ie)?',
		'JP' => 'JP|JPN|jap[ao]n',
		'KE' => 'KE|KEN|kenya',
		'KG' => 'KG|KGZ|kyrgyzstan|kirghizistan',
		'KH' => 'KH|KHM|cambodia|cambodge',
		'KI' => 'KI|KIR|kiribati',
		'KM' => 'KM|COM|(the|les)?comor[oe]s',
		'KN' => 'KN|KNA|saint kitts (and |et )?nevis',
		'KP' => "KP|PRK|(the )?democratic (people's )?republic (of )?korea|(la )?republique (populaire )?democratique (de )?coree",
		'KR' => 'KR|KOR|(the )?republic (of )?korea|(la )?republique (de )?coree',
		'KW' => 'KW|KWT|kuwait|koweit',
		'KY' => 'KY|CYM|(the )?cayman islands|((les )?iles )?caimans',
		'KZ' => 'KZ|KAZ|kazakhstan',
		'LA' => "LA|LAO|laos?|(the )?lao (people's )?(democratic )?republic|republique (democratique )?(populaire )?(d[eu] )?lao",
		'LB' => 'LB|LBN|lebanon|liban',
		'LC' => 'LC|LCA|saint lucia|sainte lucie',
		'LI' => 'LI|LIE|liechtenstein',
		'LK' => 'LK|LKA|sri lanka',
		'LR' => 'LR|LBR|liberia',
		'LS' => 'LS|LSO|lesotho',
		'LT' => 'LT|LTU|lithuani[ae]',
		'LU' => 'LU|LUX|luxembourg',
		'LV' => 'LV|LVA|latvia|lettonie',
		'LY' => 'LY|LBY|liby[ae]',
		'MA' => 'MA|MAR|morocco|maroc',
		'MC' => 'MC|MCO|monaco',
		'MD' => 'MD|MDA|((the )?republic of)?moldova|(republique de)?moldavie',
		'ME' => 'ME|MNE|montenegro',
		'MF' => 'MF|MAF|saint martin \(?(france|french|french( part| side)?)\)?|saint martin \(?(france|francaise?|(partie |cote )(francaise?|france))\)?',
		'MG' => 'MG|MDG|madagascar',
		'MH' => 'MH|MHL|marshall islands|(iles )?marshall',
		'MK' => 'MK|MKD|macedonia|macedoine',
		'ML' => 'ML|MLI|mali',
		'MM' => 'MM|MMR|myanmar',
		'MN' => 'MN|MNG|mongoli[ae]',
		'MO' => 'MO|MAC|macao',
		'MP' => 'MP|MNP|(the )?(northern )?mariana islands|((les )?iles )?mariannes ((du )?nord)?',
		'MQ' => 'MQ|MTQ|(la )?martinique',
		'MR' => 'MR|MRT|mauritani[ae]',
		'MS' => 'MS|MSR|montserrat',
		'MT' => 'MT|MLT|malt[ae]',
		'MU' => 'MU|MUS|(republic of )?mauritius|(republique de )?maurice',
		'MV' => 'MV|MDV|(les |the )?maldives',
		'MW' => 'MW|MWI|malawi',
		'MX' => 'MX|MEX|mexico|mexique',
		'MY' => 'MY|MYS|malaysia|(la )?malaisie',
		'MZ' => 'MZ|MOZ|(le )?mozambique',
		'NA' => 'NA|NAM|namibi[ae]',
		'NC' => 'NC|NCL|new caledonia|nouvelle caledonie',
		'NE' => 'NE|NER|(the |le )?niger',
		'NF' => "NF|NFK|norfolk island|((l')?ile )?norfolk",
		'NG' => 'NG|NGA|nigeria',
		'NI' => 'NI|NIC|(le )?nicaragua',
		'NL' => 'NL|NLD|(the )?netherlands|(les )?pays bas',
		'NO' => 'NO|NOR|norway|(la )?norvege',
		'NP' => 'NP|NPL|(le )?nepal',
		'NR' => 'NR|NRU|nauru',
		'NU' => 'NU|NIU|niue',
		'NZ' => 'NZ|NZL|new zealand|(la )?nouvelle zelande',
		'OM' => 'OM|OMN|oman',
		'PA' => 'PA|PAN|(le )?panama',
		'PE' => 'PE|PER|peru|(le )?perou',
		'PF' => 'PF|PYF|french polynesia|(la )?polynesie francaise',
		'PG' => 'PG|PNG|papua new guinea|(la )?papouasie nouvelle guinee',
		'PH' => 'PH|PHL|(the |les )?philippines',
		'PK' => 'PK|PAK|(le )?pakistan',
		'PL' => 'PL|POL|poland|(la )?pologne',
		'PM' => 'PM|SPM|saint pierre (et |and )?miquelon',
		'PN' => 'PN|PCN|pitcairn',
		'PR' => 'PR|PRI|p(ue|o)rto rico',
		'PS' => 'PS|PSE|(state of )?palestine|(etat de )?palestine',
		'PT' => 'PT|PRT|(le )?portugal',
		'PW' => 'PW|PLW|palau|(les )?palaos',
		'PY' => 'PY|PRY|(le )?paraguay',
		'QA' => 'QA|QAT|(le )?qatar',
		'RE' => 'RE|REU|(la )?reunion',
		'RO' => 'RO|ROU|romania|(la )?roumanie',
		'RS' => 'RS|SRB|serbia|(la )?serbie',
		'RU' => 'RU|RUS|(the )?russian federation|(la federation de )?russie',
		'RW' => 'RW|RWA|(le )?rwanda',
		'SA' => "SA|SAU|saudi arabia|(l')?arabie saoudite",
		'SB' => 'SB|SLB|solomon islands|(iles )?salomon',
		'SC' => 'SC|SYC|(les )?seychelles',
		'SD' => 'SD|SDN|(the )?sudan|(le )?soudan',
		'SE' => 'SE|SWE|sweden|(la )?suede',
		'SG' => 'SG|SGP|singapou?re?',
		'SH' => 'SH|SHN|saint helena|sainte helene|ascension|tristan da cunha|sainte? helen[ae] ascension (and |et )?tristan da cunha',
		'SI' => 'SI|SVN|sloveni[ae]',
		'SJ' => "SJ|SJM|svalbard (and |et l'ile )jan mayen?",
		'SK' => 'SK|SVK|slovakia|(la )?slovaquie',
		'SL' => 'SL|SLE|(la )?sierra leone',
		'SM' => 'SM|SMR|san marino|saint marin',
		'SN' => 'SN|SEN|(le )?senegal',
		'SO' => 'SO|SOM|(la )?somali[ae]',
		'SR' => 'SR|SUR|(le )?suriname',
		'SS' => 'SS|SSD|south sudan|(le )?soudan du sud',
		'ST' => 'ST|STP|sao tome (et |and )?principe',
		'SV' => 'SV|SLV|(el )?salvador',
		'SX' => 'SX|SXM|sint maarten \(?(dutch( part| side)?)\)?|saint martin \(?(pays bas?|(partie |cote )neerlandaise?)\)?',
		'SY' => 'SY|SYR|syrian arab republic|(la )?republique (arabe )?syrienne',
		'SZ' => 'SZ|SWZ|(le )?swaziland',
		'TC' => 'TC|TCA|(the )?turks (and )?caicos islands|((les )?iles )?turks (et )?caicos',
		'TD' => 'TD|TCD|(le )?t?chad',
		'TF' => 'TF|ATF|(the )?french southern territories|(les )?terres australes francaises',
		'TG' => 'TG|TGO|(le )?togo',
		'TH' => 'TH|THA|(la )?thailande?',
		'TJ' => 'TJ|TJK|(le )?tad?jikistan',
		'TK' => 'TK|TKL|(les )?tokelau',
		'TL' => 'TL|TLS|(le )?timor leste',
		'TM' => 'TM|TKM|(le )?turkmenistan',
		'TN' => 'TN|TUN|(la )?tunisi[ae]',
		'TO' => 'TO|TON|(les )?tonga',
		'TR' => 'TR|TUR|turkey|(la )?turquie',
		'TT' => 'TT|TTO|trinidad (and )?tobago|(la )?trinite (et )?tobago',
		'TV' => 'TV|TUV|(les )?tuvalu',
		'TW' => 'TW|TWN|taiwan|taiwan \(province of china\)|taiwan \(province de chine\)',
		'TZ' => 'TZ|TZA|tanzani[ae]|united republic of tanzania|republique unie de tanzanie',
		'UA' => "UA|UKR|(l')?ukraine",
		'UG' => "UG|UGA|(l')?o?uganda",
		'UM' => 'UM|UMI|(the )?united states minor outlying islands|(les )?iles mineures eloignees des etats unis',
		'US' => "US|USA|(the )?united states (of )?america|(les )?etats unis (d')amerique",
		'UY' => "UY|URY|(l')?uruguay",
		'UZ' => "UZ|UZB|(l')?o?uzbekistan",
		'VA' => 'VA|VAT|(the )?holy see|(le )?saint siege',
		'VC' => 'VC|VCT|saint vincent (and |et )?(the |les )?grenadines',
		'VE' => 'VE|VEN|venezuela|bolivarian republic (of )?venezuela|republique bolivarienne (du )?venezuela',
		'VG' => 'VG|VGB|virgin islands \(?british\)?|((les )?iles )?vierges britanniques',
		'VI' => 'VI|VIR|virgin islands \(?u\.?s\.?a?\.?\)?|((les )?iles )?vierges (des )?(etats unis|\(?u\.?s\.?a?\.?\)?)',
		'VN' => 'VN|VNM|(le )?viet nam',
		'VU' => 'VU|VUT|(le )?vanuatu',
		'WF' => 'WF|WLF|wallis (and |et )?futuna',
		'WS' => 'WS|WSM|(le )?samoa',
		'YE' => 'YE|YEM|(le )?yemen',
		'YT' => 'YT|MYT|mayotte',
		'ZA' => "ZA|ZAF|south africa|(l')?afrique (du )?sud",
		'ZM' => 'ZM|ZMB|(la )?zambi[ae]',
		'ZW' => 'ZW|ZWE|(le )?zimbabwe'
	);

	$countryCodeToCountry = array(
		'AD' => array('en' => 'Andorra', 'fr' => 'Andorre'),
		'AE' => array('en' => 'United Arab Emirates', 'fr' => 'Émirats arabes unis'),
		'AF' => array('en' => 'Afghanistan', 'fr' => 'Afghanistan'),
		'AG' => array('en' => 'Antigua and Barbuda', 'fr' => 'Antigua-et-Barbuda'),
		'AI' => array('en' => 'Anguilla', 'fr' => 'Anguilla'),
		'AL' => array('en' => 'Albania', 'fr' => 'Albanie'),
		'AM' => array('en' => 'Armenia', 'fr' => 'Arménie'),
		'AO' => array('en' => 'Angola', 'fr' => 'Angola'),
		'AQ' => array('en' => 'Antarctica', 'fr' => 'Antarctique'),
		'AR' => array('en' => 'Argentina', 'fr' => 'Argentine'),
		'AS' => array('en' => 'American Samoa', 'fr' => 'Samoa Américaines'),
		'AT' => array('en' => 'Austria', 'fr' => 'Autriche'),
		'AU' => array('en' => 'Australia', 'fr' => 'Australie'),
		'AW' => array('en' => 'Aruba', 'fr' => 'Aruba'),
		'AX' => array('en' => 'Åland Islands', 'fr' => 'les Îles Åland'),
		'AZ' => array('en' => 'Azerbaijan', 'fr' => 'Azerbaidjan'),
		'BA' => array('en' => 'Bosnia and Herzegovina', 'fr' => 'Bosnie-Herzégovine'),
		'BB' => array('en' => 'Barbados', 'fr' => 'Barbade'),
		'BD' => array('en' => 'Bangladesh', 'fr' => 'Bangladesh'),
		'BE' => array('en' => 'Belgium', 'fr' => 'Belgique'),
		'BF' => array('en' => 'Burkina Faso', 'fr' => 'Burkina Faso'),
		'BG' => array('en' => 'Bulgaria', 'fr' => 'Bulgarie'),
		'BH' => array('en' => 'Bahrain', 'fr' => 'Bahreïn'),
		'BI' => array('en' => 'Burundi', 'fr' => 'Burundi'),
		'BJ' => array('en' => 'Benin', 'fr' => 'Bénin'),
		'BL' => array('en' => 'Saint Barthélemy', 'fr' => 'Saint-Barthélemy'),
		'BM' => array('en' => 'Bermuda', 'fr' => 'Bermudes'),
		'BN' => array('en' => 'Brunei Darussalam', 'fr' => 'Brunéi Darussalam'),
		'BO' => array('en' => 'Bolivia', 'fr' => 'Bolivie'),
		'BQ' => array('en' => 'Bonaire, Sint Eustatius and Saba', 'fr' => 'Bonaire, Saint-Eustache et Saba'),
		'BR' => array('en' => 'Brazil', 'fr' => 'Brésil'),
		'BS' => array('en' => 'Bahamas', 'fr' => 'Bahamas'),
		'BT' => array('en' => 'Bhutan', 'fr' => 'Bhoutan'),
		'BV' => array('en' => 'Bouvet Island', 'fr' => "L'île Bouvet"),
		'BW' => array('en' => 'Botswana', 'fr' => 'Botswana'),
		'BY' => array('en' => 'Belarus', 'fr' => 'Bélarus'),
		'BZ' => array('en' => 'Belize', 'fr' => 'Bélize'),
		'CA' => array('en' => 'Canada', 'fr' => 'Canada'),
		'CC' => array('en' => 'Cocos (Keeling) Island', 'fr' => 'Îles Cocos (Keeling)'),
		'CD' => array('en' => 'the Democratic Republic of the Congo', 'fr' => 'la République démocratique du Congo'),
		'CF' => array('en' => 'Central African Republic', 'fr' => 'République centrafricaine'),
		'CG' => array('en' => 'Congo', 'fr' => 'Congo'),
		'CH' => array('en' => 'Switzerland', 'fr' => 'Suisse'),
		'CI' => array('en' => "Côte d'Ivoire", 'fr' => "Côte d'Ivoire"),
		'CK' => array('en' => 'Cook Islands', 'fr' => 'Les Îles Cook'),
		'CL' => array('en' => 'Chile', 'fr' => 'Chili'),
		'CM' => array('en' => 'Cameroon', 'fr' => 'Cameroun'),
		'CN' => array('en' => 'China', 'fr' => 'Chine'),
		'CO' => array('en' => 'Colombia', 'fr' => 'Colombie'),
		'CR' => array('en' => 'Costa Rica', 'fr' => 'Costa Rica'),
		'CU' => array('en' => 'Cuba', 'fr' => 'Cuba'),
		'CV' => array('en' => 'Cabo Verde', 'fr' => 'Cabo Verde'),
		'CW' => array('en' => 'Curaçao', 'fr' => 'Curaçao'),
		'CX' => array('en' => 'Christmas Island', 'fr' => "L'île Christmas"),
		'CY' => array('en' => 'Cyprus', 'fr' => 'Chypre'),
		'CZ' => array('en' => 'Czechia', 'fr' => 'Tchéquie'),
		'DE' => array('en' => 'Germany', 'fr' => 'Allemagne'),
		'DJ' => array('en' => 'Djibouti', 'fr' => 'Djibouti'),
		'DK' => array('en' => 'Denmark', 'fr' => 'Danemark'),
		'DM' => array('en' => 'Dominica', 'fr' => 'Dominique'),
		'DO' => array('en' => 'Dominican Republic', 'fr' => 'République dominicaine'),
		'DZ' => array('en' => 'Algeria', 'fr' => 'Algérie'),
		'EC' => array('en' => 'Ecuador', 'fr' => 'Equateur'),
		'EE' => array('en' => 'Estonia', 'fr' => 'Estonie'),
		'EG' => array('en' => 'Egypt', 'fr' => 'Égypte'),
		'EH' => array('en' => 'Western Sahara', 'fr' => 'Sahara occidental'),
		'ER' => array('en' => 'Eritrea', 'fr' => 'Érythrée'),
		'ES' => array('en' => 'Spain', 'fr' => 'Espagne'),
		'ET' => array('en' => 'Ethiopia', 'fr' => 'Éthiopie'),
		'FI' => array('en' => 'Finland', 'fr' => 'Finlande'),
		'FJ' => array('en' => 'Fiji', 'fr' => 'Fidji'),
		'FK' => array('en' => 'Falkland Islands', 'fr' => 'Les îles Falkland'),
		'FM' => array('en' => 'Micronesia', 'fr' => 'Micronésie'),
		'FO' => array('en' => 'Faroe Islands', 'fr' => 'Les îles Féroé'),
		'FR' => array('en' => 'France', 'fr' => 'France'),
		'GA' => array('en' => 'Gabon', 'fr' => 'Gabon'),
		'GB' => array('en' => 'United Kingdom of Great Britain and Northern Ireland', 'fr' => "Royaume-Uni de Grande-Bretagne et d'Irlande du Nord"),
		'GD' => array('en' => 'Grenada', 'fr' => 'Grenade'),
		'GE' => array('en' => 'Georgia', 'fr' => 'Géorgie'),
		'GF' => array('en' => 'French Guiana', 'fr' => 'Guyane française'),
		'GG' => array('en' => 'Guernsey', 'fr' => 'Guernesey'),
		'GH' => array('en' => 'Ghana', 'fr' => 'Ghana'),
		'GI' => array('en' => 'Gibraltar', 'fr' => 'Gibraltar'),
		'GL' => array('en' => 'Greenland', 'fr' => 'groenland'),
		'GM' => array('en' => 'Gambia', 'fr' => 'Gambie'),
		'GN' => array('en' => 'Guinea', 'fr' => 'Guinée'),
		'GP' => array('en' => 'Guadeloupe', 'fr' => 'Guadeloupe'),
		'GQ' => array('en' => 'Equatorial Guinea', 'fr' => 'Guinée équatoriale'),
		'GR' => array('en' => 'Greece', 'fr' => 'Grèce'),
		'GS' => array('en' => 'South Georgia and the South Sandwich Islands', 'fr' => 'Géorgie du Sud-et-les îles Sandwich du Sud'),
		'GT' => array('en' => 'Guatemala', 'fr' => 'Guatemala'),
		'GU' => array('en' => 'Guam', 'fr' => 'Guam'),
		'GW' => array('en' => 'Guinea-Bissau', 'fr' => 'Guinée-Bissau'),
		'GY' => array('en' => 'Guyana', 'fr' => 'Guyana'),
		'HK' => array('en' => 'Hong Kong', 'fr' => 'Hong Kong'),
		'HM' => array('en' => 'Heard Island and McDonald Islands', 'fr' => "L'Île Heard-et-MacDonald"),
		'HN' => array('en' => 'Honduras', 'fr' => 'Honduras'),
		'HR' => array('en' => 'Croatia', 'fr' => 'Croatie'),
		'HT' => array('en' => 'Haiti', 'fr' => 'Haïti'),
		'HU' => array('en' => 'hungary', 'fr' => 'hongrie'),
		'ID' => array('en' => 'Indonesia', 'fr' => 'Indonésie'),
		'IE' => array('en' => 'Ireland', 'fr' => 'Irlande'),
		'IL' => array('en' => 'Israel', 'fr' => 'Israël'),
		'IM' => array('en' => 'Isle of Man', 'fr' => 'Île de Man'),
		'IN' => array('en' => 'India', 'fr' => 'Inde'),
		'IO' => array('en' => 'British Indian Ocean Territory', 'fr' => "Le Territoire britannique de l'océan Indien"),
		'IQ' => array('en' => 'Iraq', 'fr' => 'Irak'),
		'IR' => array('en' => 'Iran', 'fr' => 'Iran'),
		'IS' => array('en' => 'Iceland', 'fr' => 'Islande'),
		'IT' => array('en' => 'Italy', 'fr' => 'Italie'),
		'JE' => array('en' => 'Jersey', 'fr' => 'Jersey'),
		'JM' => array('en' => 'Jamaica', 'fr' => 'Jamaïque'),
		'JO' => array('en' => 'Jordan', 'fr' => 'Jordanie'),
		'JP' => array('en' => 'Japan', 'fr' => 'Japon'),
		'KE' => array('en' => 'Kenya', 'fr' => 'Kenya'),
		'KG' => array('en' => 'Kyrgyzstan', 'fr' => 'Kirghizistan'),
		'KH' => array('en' => 'Cambodia', 'fr' => 'Cambodge'),
		'KI' => array('en' => 'Kiribati', 'fr' => 'Kiribati'),
		'KM' => array('en' => 'Comoros', 'fr' => 'Comores'),
		'KN' => array('en' => 'Saint Kitts and Nevis', 'fr' => 'Saint-Kitts-et-Nevis'),
		'KP' => array('en' => "The Democratic People's Republic of Korea", 'fr' => 'La République populaire démocratique de Corée'),
		'KR' => array('en' => 'The Republic of Korea', 'fr' => 'La République de Corée'),
		'KW' => array('en' => 'Kuwait', 'fr' => 'Koweit'),
		'KY' => array('en' => 'Cayman Islands', 'fr' => 'Les Îles Caïmans'),
		'KZ' => array('en' => 'Kazakhstan', 'fr' => 'Kazakhstan'),
		'LA' => array('en' => "Lao People's Democratic Republic", 'fr' => 'République démocratique populaire de Lao'),
		'LB' => array('en' => 'Lebanon', 'fr' => 'Liban'),
		'LC' => array('en' => 'Saint Lucia', 'fr' => 'Sainte-Lucie'),
		'LI' => array('en' => 'Liechtenstein', 'fr' => 'Liechtenstein'),
		'LK' => array('en' => 'Sri Lanka', 'fr' => 'Sri Lanka'),
		'LR' => array('en' => 'Liberia', 'fr' => 'Libéria'),
		'LS' => array('en' => 'Lesotho', 'fr' => 'Lesotho'),
		'LT' => array('en' => 'Lithuania', 'fr' => 'Lithuanie'),
		'LU' => array('en' => 'Luxembourg', 'fr' => 'Luxembourg'),
		'LV' => array('en' => 'Latvia', 'fr' => 'Lettonie'),
		'LY' => array('en' => 'Libya', 'fr' => 'Libye'),
		'MA' => array('en' => 'Morocco', 'fr' => 'Maroc'),
		'MC' => array('en' => 'Monaco', 'fr' => 'Monaco'),
		'MD' => array('en' => 'Moldova', 'fr' => 'Moldavie'),
		'ME' => array('en' => 'Montenegro', 'fr' => 'Monténégro'),
		'MF' => array('en' => 'Saint Martin (French Part)', 'fr' => 'Saint-Martin (partie française)'),
		'MG' => array('en' => 'Madagascar', 'fr' => 'Madagascar'),
		'MH' => array('en' => 'Marshall Islands', 'fr' => 'Îles Marshall'),
		'MK' => array('en' => 'Macedonia', 'fr' => 'Macédoine'),
		'ML' => array('en' => 'Mali', 'fr' => 'Mali'),
		'MM' => array('en' => 'Myanmar', 'fr' => 'Myanmar'),
		'MN' => array('en' => 'Mongolia', 'fr' => 'Mongolie'),
		'MO' => array('en' => 'Macao', 'fr' => 'Macao'),
		'MP' => array('en' => 'Northern Mariana Islands', 'fr' => 'Îles Mariannes du Nord'),
		'MQ' => array('en' => 'Martinique', 'fr' => 'Martinique'),
		'MR' => array('en' => 'Mauritania', 'fr' => 'Mauritanie'),
		'MS' => array('en' => 'Montserrat', 'fr' => 'Montserrat'),
		'MT' => array('en' => 'Malta', 'fr' => 'Malte'),
		'MU' => array('en' => 'Mauritius', 'fr' => 'Maurice'),
		'MV' => array('en' => 'Maldives', 'fr' => 'Maldives'),
		'MW' => array('en' => 'Malawi', 'fr' => 'Malawi'),
		'MX' => array('en' => 'Mexico', 'fr' => 'Mexique'),
		'MY' => array('en' => 'Malaysia', 'fr' => 'Malaisie'),
		'MZ' => array('en' => 'Mozambique', 'fr' => 'Mozambique'),
		'NA' => array('en' => 'namibia', 'fr' => 'namibie'),
		'NC' => array('en' => 'New Caledonia', 'fr' => 'Nouvelle-Calédonie'),
		'NE' => array('en' => 'Niger', 'fr' => 'Niger'),
		'NF' => array('en' => 'Norfolk Island', 'fr' => "Île Norfolk"),
		'NG' => array('en' => 'Nigeria', 'fr' => 'Nigéria'),
		'NI' => array('en' => 'Nicaragua', 'fr' => 'Nicaragua'),
		'NL' => array('en' => 'Netherlands', 'fr' => 'Pays-Bas'),
		'NO' => array('en' => 'Norway', 'fr' => 'Norvège'),
		'NP' => array('en' => 'Nepal', 'fr' => 'Népal'),
		'NR' => array('en' => 'Nauru', 'fr' => 'Nauru'),
		'NU' => array('en' => 'Niue', 'fr' => 'Niue'),
		'NZ' => array('en' => 'New Zealand', 'fr' => 'Nouvelle-Zélande'),
		'OM' => array('en' => 'Oman', 'fr' => 'Oman'),
		'PA' => array('en' => 'Panama', 'fr' => 'Panama'),
		'PE' => array('en' => 'Peru', 'fr' => 'Pérou'),
		'PF' => array('en' => 'French Polynesia', 'fr' => 'Polynésie française'),
		'PG' => array('en' => 'Papua New Guinea', 'fr' => 'Papouasie-Nouvelle-Guinée'),
		'PH' => array('en' => 'Philippines', 'fr' => 'Philippines'),
		'PK' => array('en' => 'Pakistan', 'fr' => 'Pakistan'),
		'PL' => array('en' => 'Poland', 'fr' => 'Pologne'),
		'PM' => array('en' => 'Saint Pierre and Miquelon', 'fr' => 'Saint-Pierre-et-Miquelon'),
		'PN' => array('en' => 'Pitcairn', 'fr' => 'Pitcairn'),
		'PR' => array('en' => 'Puerto Rico', 'fr' => 'Porto Rico'),
		'PS' => array('en' => 'Palestine', 'fr' => 'Palestine'),
		'PT' => array('en' => 'Portugal', 'fr' => 'Portugal'),
		'PW' => array('en' => 'Palau', 'fr' => 'Palaos'),
		'PY' => array('en' => 'Paraguay', 'fr' => 'Paraguay'),
		'QA' => array('en' => 'Qatar', 'fr' => 'Qatar'),
		'RE' => array('en' => 'Réunion', 'fr' => 'Réunion'),
		'RO' => array('en' => 'Romania', 'fr' => 'Roumanie'),
		'RS' => array('en' => 'Serbia', 'fr' => 'Serbie'),
		'RU' => array('en' => 'Russian Federation', 'fr' => 'Russie'),
		'RW' => array('en' => 'Rwanda', 'fr' => 'Rwanda'),
		'SA' => array('en' => 'Saudi Arabia', 'fr' => 'Arabie saoudite'),
		'SB' => array('en' => 'Solomon Islands', 'fr' => 'Îles Salomon'),
		'SC' => array('en' => 'Seychelles', 'fr' => 'Seychelles'),
		'SD' => array('en' => 'Sudan', 'fr' => 'Soudan'),
		'SE' => array('en' => 'Sweden', 'fr' => 'Suède'),
		'SG' => array('en' => 'Singapore', 'fr' => 'Singapour'),
		'SH' => array('en' => 'Saint Helena Ascension and Tristan da Cunha', 'fr' => 'Sainte-Héléne Ascension et Tristan da Cunha'),
		'SI' => array('en' => 'Slovenia', 'fr' => 'Slovénie'),
		'SJ' => array('en' => 'Svalbard and Jan Mayen', 'fr' => "Svalbard et l'Île Jan Mayen"),
		'SK' => array('en' => 'Slovakia', 'fr' => 'Slovaquie'),
		'SL' => array('en' => 'Sierra Leone', 'fr' => 'Sierra Leone'),
		'SM' => array('en' => 'San Marino', 'fr' => 'Saint-Marin'),
		'SN' => array('en' => 'Senegal', 'fr' => 'Sénégal'),
		'SO' => array('en' => 'Somalia', 'fr' => 'Somalie'),
		'SR' => array('en' => 'Suriname', 'fr' => 'Suriname'),
		'SS' => array('en' => 'South Sudan', 'fr' => 'Soudan du Sud'),
		'ST' => array('en' => 'Sao Tome and Principe', 'fr' => 'Sao Tomé-et-Principe'),
		'SV' => array('en' => 'El Salvador', 'fr' => 'Salvador'),
		'SX' => array('en' => 'Sint Maarten (Dutch part)', 'fr' => 'Saint-Martin (partie néerlandaise)'),
		'SY' => array('en' => 'Syrian Arab Republic', 'fr' => 'République arabe syrienne'),
		'SZ' => array('en' => 'Swaziland', 'fr' => 'Swaziland'),
		'TC' => array('en' => 'Turks and Caicos Islands', 'fr' => 'Ïles Turks-et-Caïcos'),
		'TD' => array('en' => 'Chad', 'fr' => 'Tchad'),
		'TF' => array('en' => 'French Southern Territories', 'fr' => 'Terres australes françaises'),
		'TG' => array('en' => 'Togo', 'fr' => 'Togo'),
		'TH' => array('en' => 'Thailand', 'fr' => 'Thaïlande'),
		'TJ' => array('en' => 'Tajikistan', 'fr' => 'Tadjikistan'),
		'TK' => array('en' => 'Tokelau', 'fr' => 'Tokelau'),
		'TL' => array('en' => 'Timor-Leste', 'fr' => 'Timor-Leste'),
		'TM' => array('en' => 'Turkmenistan', 'fr' => 'Turkménistan'),
		'TN' => array('en' => 'Tunisia', 'fr' => 'Tunisie'),
		'TO' => array('en' => 'Tonga', 'fr' => 'Tonga'),
		'TR' => array('en' => 'Turkey', 'fr' => 'Turquie'),
		'TT' => array('en' => 'Trinidad and Tobago', 'fr' => 'Trinité-et-Tobago'),
		'TV' => array('en' => 'Tuvalu', 'fr' => 'Tuvalu'),
		'TW' => array('en' => 'Taiwan', 'fr' => 'Taiwan'),
		'TZ' => array('en' => 'Tanzania', 'fr' => 'Tanzanie'),
		'UA' => array('en' => 'Ukraine', 'fr' => 'Ukraine'),
		'UG' => array('en' => 'Uganda', 'fr' => 'Ouganda'),
		'UM' => array('en' => 'United States Minor Outlying Islands', 'fr' => 'Îles mineures éloignées des États-Unis'),
		'US' => array('en' => 'United States of America', 'fr' => "États-Unis d'Amérique"),
		'UY' => array('en' => 'Uruguay', 'fr' => 'Uruguay'),
		'UZ' => array('en' => 'Uzbekistan', 'fr' => 'Ouzbékistan'),
		'VA' => array('en' => 'Holy See', 'fr' => 'Saint-Siège'),
		'VC' => array('en' => 'Saint Vincent and the Grenadines', 'fr' => 'Saint-Vincent-et-les-Grenadines'),
		'VE' => array('en' => 'Venezuela', 'fr' => 'Venezuela'),
		'VG' => array('en' => 'Virgin Islands (British)', 'fr' => 'Îles Vierges britanniques'),
		'VI' => array('en' => 'Virgin Islands (U.S.)', 'fr' => 'Îles Vierges des États-Unis'),
		'VN' => array('en' => 'Viet Nam', 'fr' => 'Viet Nam'),
		'VU' => array('en' => 'Vanuatu', 'fr' => 'Vanuatu'),
		'WF' => array('en' => 'Wallis and Futuna', 'fr' => 'Wallis-et-Futuna'),
		'WS' => array('en' => 'Samoa', 'fr' => 'Samoa'),
		'YE' => array('en' => 'Yemen', 'fr' => 'Yémen'),
		'YT' => array('en' => 'Mayotte', 'fr' => 'Mayotte'),
		'ZA' => array('en' => 'South Africa', 'fr' => 'Afrique du Sud'),
		'ZM' => array('en' => 'Zambia', 'fr' => 'Zambie'),
		'ZW' => array('en' => 'Zimbabwe', 'fr' => 'Zimbabwe')
	);


	//List of country phone codes
	$countryPhoneCode = array(
		"AC" => 247, "AD" => 376, "AE" => 971, "AF" => 93, "AG" => 1268, "AI" => 1264, "AL" => 355, "AM" => 374, "AN" => 599, "AO" => 244, "AQ" => 672, "AR" => 54, "AS" => 1684,
		"AT" => 43, "AU" => 61, "AW" => 297, "AZ" => 994, "BA" => 387, "BB" => 1246, "BD" => 880, "BE" => 32, "BF" => 226, "BG" => 359, "BH" => 973, "BI" => 257, "BJ" => 229,
		"BM" => 1441, "BN" => 673, "BO" => 591, "BR" => 55, "BS" => 1242, "BT" => 975, "BV" => 0, "BW" => 267, "BY" => 375, "BZ" => 501, "CA" => 1, "CC" => 61, "CD" => 243, "CF" => 236,
		"CG" => 242, "CH" => 41, "CI" => 225, "CK" => 682, "CL" => 56, "CM" => 237, "CN" => 86, "CO" => 57, "CR" => 506, "CU" => 53, "CV" => 238, "CX" => 61, "CY" => 357, "CZ" => 420,
		"DE" => 49, "DJ" => 253, "DK" => 45, "DM" => 1767, "DO" => 1, "DZ" => 213, "EC" => 593, "EE" => 372, "EG" => 20, "EH" => 212, "ER" => 291, "ES" => 34, "ET" => 251, "FI" => 358,
		"FJ" => 679, "FK" => 500, "FM" => 691, "FO" => 298, "FR" => 33, "GA" => 241, "GB" => 44, "GD" => 1, "GE" => 995, "GF" => 594, "GG" => 44, "GH" => 233, "GI" => 350,
		"GL" => 299, "GM" => 220, "GN" => 224, "GP" => 590, "GQ" => 240, "GR" => 30, "GS" => 0, "GT" => 502, "GU" => 1671, "GW" => 245, "GY" => 592, "HK" => 852, "HM" => 0,
		"HN" => 504, "HR" => 385, "HT" => 509, "HU" => 36, "ID" => 62, "IE" => 353, "IL" => 972, "IM" => 44, "IN" => 91, "IO" => 246, "IQ" => 964, "IR" => 98, "IS" => 354,
		"IT" => 39, "JE" => 44, "JM" => 1, "JO" => 962, "JP" => 81, "KE" => 254, "KG" => 996, "KH" => 855, "KI" => 686, "KM" => 269, "KN" => 1869, "KP" => 850, "KR" => 82, "KW" => 965,
		"KY" => 1345, "KZ" => 7, "LA" => 856, "LB" => 961, "LC" => 1758, "LI" => 423, "LK" => 94, "LR" => 231, "LS" => 266, "LT" => 370, "LU" => 352, "LV" => 371, "LY" => 218, "MA" => 212,
		"MC" => 377, "MD" => 373, "MG" => 261, "MH" => 692, "MK" => 389, "ML" => 223, "MM" => 95, "MN" => 976, "MO" => 853, "MP" => 1670, "MQ" => 596, "MR" => 222, "MS" => 1664, "MT" => 356,
		"MU" => 230, "MV" => 960, "MW" => 265, "MX" => 52, "MY" => 60, "MZ" => 258, "NA" => 264, "NC" => 687, "NE" => 227, "NF" => 672, "NG" => 234, "NI" => 505, "NL" => 31, "NO" => 47,
		"NP" => 977, "NR" => 674, "NU" => 683, "NZ" => 64, "OM" => 968, "PA" => 507, "PE" => 51, "PF" => 689, "PG" => 675, "PH" => 63, "PK" => 92, "PL" => 48, "PM" => 508, "PN" => 64,
		"PR" => 1, "PS" => 970, "PT" => 351, "PW" => 680, "PY" => 595, "QA" => 974, "RE" => 262, "RO" => 40, "RS" => 381, "RU" => 7, "RW" => 250, "SA" => 966, "SB" => 677, "SC" => 248,
		"SD" => 249, "SE" => 46, "SG" => 65, "SH" => 290, "SI" => 386, "SJ" => 47, "SK" => 421, "SL" => 232, "SM" => 378, "SN" => 221, "SO" => 252, "SR" => 597, "ST" => 239, "SV" => 503, "SX" => 1721,
		"SY" => 963, "SZ" => 268, "TC" => 1649, "TD" => 235, "TF" => 0, "TG" => 228, "TH" => 66, "TJ" => 992, "TK" => 690, "TM" => 993, "TN" => 216, "TO" => 676, "TR" => 90, "TT" => 1868,
		"TV" => 688, "TW" => 886, "TZ" => 255, "UA" => 380, "UG" => 256, "UM" => 0, "US" => 1, "UY" => 598, "UZ" => 998, "VA" => 379, "VC" => 1784, "VE" => 58, "VG" => 1284, "VI" => 1340, "VN" => 84,
		"VU" => 678, "WF" => 681, "WS" => 685, "YE" => 967, "YT" => 269, "ZA" => 27, "ZM" => 260, "ZW" => 263
	);

	//List of state code
	//AUSTRALIA
	$stateCodeToRegex['AU'] = array(
		'NSW' => 'NSW|new south wales', 'VIC' => 'VIC|victoria', 'QLD' => 'QLD|queensland', 'ACT' => 'ACT|australian capital territory', 'NT' => 'NT|northern territory',
		'TAS' => 'TAS|tasmania', 'WA'  => 'WA|western australia', 'SA'  => 'SA|south australia'
	);
	$stateCodeToState["AU"] = array(
		'NSW' => 'New South Wales', 'QLD' => 'Queensland', 'SA' => 'South Australia', 'TAS' => 'Tasmania', 'VIC' => 'Victoria', 'WA' => 'Western Australia',
		'ACT' => 'Australian Capital Territory', 'NT' => 'Northern Territory'
	);
	//BRAZIL			
	$stateCodeToRegex['BR'] = array(
		"AC" => "AC|acre", "AL" => "AL|alagoas", "AM" => "AM|amazonas", "AP" => "AP|amapa", "BA" => "BA|bahia", "CE" => "CE|ceara", "DF" => "DF|distrito federal",
		"ES" => "ES|espirito santo", "GO" => "GO|goias", "MA" => "MA|maranhao", "MG" => "MG|minas gerais", "MS" => "MS|mato grosso( do)? sul", "MT" => "MT|mato grosso",
		"PA" => "PA|para", "PB" => "PB|paraiba", "PE" => "PE|pernambuco", "PI" => "PI|piaui", "PR" => "PR|parana", "RJ" => "RJ|rio (de )?janeiro", "RN" => "RN|rio grande (do )?norte",
		"RO" => "RO|rondonia", "RR" => "RR|roraima", "RS" => "RS|rio grande( do)? sul", "SC" => "SC|santa catarina", "SE" => "SE|sergipe", "SP" => "SP|sao paulo",
		"TO" => "TO|tocantins"
	);
	$stateCodeToState["BR"] = array(
		"AC" => "Acre", "AL" => "Alagoas", "AM" => "Amazonas", "AP" => "Amapá", "BA" => "Bahia", "CE" => "Ceará", "DF" => "Distrito Federal",
		"ES" => "Espírito Santo", "GO" => "Goiás", "MA" => "Maranhão", "MG" => "Minas Gerais", "MS" => "Mato Grosso do Sul", "MT" => "Mato Grosso",
		"PA" => "Pará", "PB" => "Paraíba", "PE" => "Pernambuco", "PI" => "Piauí", "PR" => "Paraná", "RJ" => "Rio de Janeiro", "RN" => "Rio Grande do Norte",
		"RO" => "Rondônia", "RR" => "Roraima", "RS" => "Rio Grande do Sul", "SC" => "Santa Catarina", "SE" => "Sergipe", "SP" => "São Paulo",
		"TO" => "Tocantins"
	);
	//CANADA
	$stateCodeToRegex['CA'] = array(
		'AB' => 'AB|alberta',
		'BC' => 'BC|british columbia|colombie britannique',
		'MB' => 'MB|manitoba',
		'NB' => 'NB|(new |nouveau )?brunswick',
		'NL' => 'NL|newfoundland( and labrador)?|terre neuve( et)?( labrador)?',
		'NT' => 'NT|northwest territories|territoires (du )?nord ouest',
		'NS' => 'NS|nova scotia|nouvelle ecosse',
		'NU' => 'NU|nunavut',
		'ON' => 'ON|ontario',
		'PE' => 'PE|prince edward( island)?|(iles? (du )?)?prince edouard',
		'QC' => 'QC|quebec',
		'SK' => 'SK|saskatchewan',
		'YT' => 'YT|yukon( territory)?'
	);
	$stateCodeToState["CA"] = array(
		'AB' => array('en' => 'Alberta', 'fr' => 'Alberta'),
		'BC' => array('en' => 'British Columbia', 'fr' => 'Colombie-Britannique'),
		'MB' => array('en' => 'Manitoba', 'fr' => 'Manitoba'),
		'NB' => array('en' => 'New Brunswick', 'fr' => 'Nouveau-Brunswick'),
		'NL' => array('en' => 'Newfoundland and Labrador', 'fr' => 'Terre-Neuve-et-Labrador'),
		'NT' => array('en' => 'Northwest Territories', 'fr' => 'Territoires du Nord-Ouest'),
		'NS' => array('en' => 'Nova scotia', 'fr' => 'Nouvelle-Écosse'),
		'NU' => array('en' => 'Nunavut', 'fr' => 'Nunavut'),
		'ON' => array('en' => 'Ontario', 'fr' => 'Ontario'),
		'PE' => array('en' => 'Prince Edward Island', 'fr' => 'Îles-du-Prince-Édouard'),
		'QC' => array('en' => 'Québec', 'fr' => 'Québec'),
		'SK' => array('en' => 'Saskatchewan', 'fr' => 'Saskatchewan'),
		'YT' => array('en' => 'Yukon Territory', 'fr' => 'Yukon')
	);
	//ITALIA
	$stateCodeToRegex["IT"] = array(
		"AG" => "AG|agrigento", "AL" => "AL|alessandria", "AN" => "AN|ancona", "AO" => "AO|aosta", "AP" => "AP|ascoli piceno", "AQ" => "AQ|(L')?aquila",
		"AR" => "AR|arezzo", "AT" => "AT|asti", "AV" => "AV|avellino", "BA" => "BA|bari", "BG" => "BG|bergamo", "BI" => "BI|biella", "BL" => "BL|belluno",
		"BN" => "BN|benevento", "BO" => "BO|bologna", "BR" => "BR|brindisi", "BS" => "BS|brescia", "BT" => "BT|barletta andria trani", "BZ" => "BZ|bolzano", "CA" => "CA|cagliari",
		"CB" => "CB|campobasso", "CE" => "CE|caserta", "CH" => "CH|chieti", "CI" => "CI|carbonia iglesias", "CL" => "CL|caltanissetta", "CN" => "CN|cuneo", "CO" => "CO|como",
		"CR" => "CR|cremona", "CS" => "CS|cosenza", "CT" => "CT|catania", "CZ" => "CZ|catanzaro", "EN" => "EN|enna", "FC" => "FC|forli cesena", "FE" => "FE|ferrara",
		"FG" => "FG|foggia", "FI" => "FI|florence", "FM" => "FM|fermo", "FR" => "FR|frosinone", "GE" => "GE|genoa", "GO" => "GO|gorizia", "GR" => "GR|grosseto", "IM" => "IM|imperia",
		"IS" => "IS|isernia", "KR" => "KR|crotone", "LC" => "LC|lecco", "LE" => "LE|lecce", "LI" => "LI|livorno", "LO" => "LO|lodi", "LT" => "LT|latina", "LU" => "LU|lucca",
		"MB" => "MB|monza and Brianza", "MC" => "MC|macerata", "ME" => "ME|messina", "MI" => "MI|milan", "MN" => "MN|mantua", "MO" => "MO|modena", "MS" => "MS|massa (and )?carrara",
		"MT" => "MT|matera", "NA" => "NA|naples", "NO" => "NO|novara", "NU" => "NU|nuoro", "OG" => "OG|ogliastra", "OR" => "OR|oristano", "OT" => "OT|olbia tempio", "PA" => "PA|palermo",
		"PC" => "PC|piacenza", "PD" => "PD|padua", "PE" => "PE|pescara", "PG" => "PG|perugia", "PI" => "PI|pisa", "PN" => "PN|pordenone", "PO" => "PO|prato", "PR" => "PR|parma",
		"PT" => "PT|pistoia", "PU" => "PU|pesaro (and )?urbino", "PV" => "PV|pavia", "PZ" => "PZ|potenza", "RA" => "RA|ravenna", "RC" => "RC|reggio calabria", "RE" => "RE|reggio Emilia",
		"RG" => "RG|ragusa", "RI" => "RI|rieti", "RM" => "RM|rome", "RN" => "RN|rimini", "RO" => "RO|rovigo", "SA" => "SA|salerno", "SI" => "SI|siena", "SO" => "SO|sondrio",
		"SP" => "SP|(La )?spezia", "SR" => "SR|syracuse", "SS" => "SS|sassari", "SV" => "SV|savona", "TA" => "TA|taranto", "TE" => "TE|teramo", "TN" => "TN|trento", "TO" => "TO|turin(o)?",
		"TP" => "TP|trapani", "TR" => "TR|terni", "TS" => "TS|trieste", "TV" => "TV|treviso", "UD" => "UD|udine", "VA" => "VA|varese", "VB" => "VB|verbano cusio ossola",
		"VC" => "VC|vercelli", "VE" => "VE|venice", "VI" => "VI|vicenza", "VR" => "VR|verona", "VS" => "VS|medio campidano", "VT" => "VT|viterbo", "VV" => "VV|vibo valentia"
	);
	$stateCodeToState["IT"] = array(
		"AG" => "Agrigento", "AL" => "Alessandria", "AN" => "Ancona", "AO" => "Aosta", "AP" => "Ascoli Piceno", "AQ" => "L'Aquila", "AR" => "Arezzo",
		"AT" => "Asti", "AV" => "Avellino", "BA" => "Bari", "BG" => "Bergamo", "BI" => "Biella", "BL" => "Belluno", "BN" => "Benevento", "BO" => "Bologna", "BR" => "Brindisi",
		"BS" => "Brescia", "BT" => "Barletta-Andria-Trani", "BZ" => "Bolzano", "CA" => "Cagliari", "CB" => "Campobasso", "CE" => "Caserta", "CH" => "Chieti", "CI" => "Carbonia-Iglesias",
		"CL" => "Caltanissetta", "CN" => "Cuneo", "CO" => "Como", "CR" => "Cremona", "CS" => "Cosenza", "CT" => "Catania", "CZ" => "Catanzaro", "EN" => "Enna", "FC" => "Forlì-Cesena",
		"FE" => "Ferrara", "FG" => "Foggia", "FI" => "Florence", "FM" => "Fermo", "FR" => "Frosinone", "GE" => "Genoa", "GO" => "Gorizia", "GR" => "Grosseto", "IM" => "Imperia",
		"IS" => "Isernia", "KR" => "Crotone", "LC" => "Lecco", "LE" => "Lecce", "LI" => "Livorno", "LO" => "Lodi", "LT" => "Latina", "LU" => "Lucca", "MB" => "Monza and Brianza",
		"MC" => "Macerata", "ME" => "Messina", "MI" => "Milan", "MN" => "Mantua", "MO" => "Modena", "MS" => "Massa and Carrara", "MT" => "Matera", "NA" => "Naples", "NO" => "Novara",
		"NU" => "Nuoro", "OG" => "Ogliastra", "OR" => "Oristano", "OT" => "Olbia-Tempio", "PA" => "Palermo", "PC" => "Piacenza", "PD" => "Padua", "PE" => "Pescara", "PG" => "Perugia",
		"PI" => "Pisa", "PN" => "Pordenone", "PO" => "Prato", "PR" => "Parma", "PT" => "Pistoia", "PU" => "Pesaro and Urbino", "PV" => "Pavia", "PZ" => "Potenza", "RA" => "Ravenna",
		"RC" => "Reggio Calabria", "RE" => "Reggio Emilia", "RG" => "Ragusa", "RI" => "Rieti", "RM" => "Rome", "RN" => "Rimini", "RO" => "Rovigo", "SA" => "Salerno", "SI" => "Siena",
		"SO" => "Sondrio", "SP" => "La Spezia", "SR" => "Syracuse", "SS" => "Sassari", "SV" => "Savona", "TA" => "Taranto", "TE" => "Teramo", "TN" => "Trento", "TO" => "Turin",
		"TP" => "Trapani", "TR" => "Terni", "TS" => "Trieste", "TV" => "Treviso", "UD" => "Udine", "VA" => "Varese", "VB" => "Verbano-Cusio-Ossola", "VC" => "Vercelli",
		"VE" => "Venice", "VI" => "Vicenza", "VR" => "Verona", "VS" => "Medio Campidano", "VT" => "Viterbo", "VV" => "Vibo Valentia",
	);
	//MEXICO				
	$stateCodeToRegex['MX'] = array(
		"AG" => "AG|AGUASCALIENTES", "BC" => "BC|BAJA CALIFORNIA", "BS" => "BS|BAJA CALIFORNIA SUR", "CO" => "CO|COAHUILA", "CH" => "CH|CHIHUAHUA",
		"CL" => "CL|COLIMA", "CM" => "CM|CAMPECHE", "CS" => "CS|CHIAPAS", "DF" => "DF|MEXICO( CITY)?", "DG" => "DG|DURANGO", "EM" => "EM|MEXICO STATE",
		"GR" => "GR|GUERRERO", "GT" => "GT|GUANAJUATO", "HG" => "HG|HIDALGO", "JA" => "JA|JALISCO", "MI" => "MI|MICHOACAN", "MO" => "MO|MORELOS",
		"NA" => "NA|NAYARIT", "NL" => "NL|NEW LEON|NUEVO LEON", "OA" => "OA|OAXACA", "PU" => "PU|PUEBLA", "QE" => "QE|QUERETARO", "QR" => "QR|QUINTANA ROO",
		"SI" => "SI|SINALOA", "SL" => "SL|SAN LUIS POTOSI", "SO" => "SO|SONORA", "TB" => "TB|TABASCO", "TL" => "TL|TLAXCALA", "TM" => "TM|TAMAULIPAS",
		"VE" => "VE|VERACRUZ", "YU" => "YU|YUCATAN", "ZA" => "ZA|ZACATECAS"
	);
	$stateCodeToState['MX'] = array(
		"AG" => "Aguascalientes", "BC" => "Baja California", "BS" => "Baja California Sur", "CH" => "Chihuahua", "CL" => "Colima",
		"CM" => "Campeche", "CO" => "Coahuila", "CS" => "Chiapas", "DF" => "Mexico City", "DG" => "Durango", "GR" => "Guerrero", "GT" => "Guanajuato",
		"HG" => "Hidalgo", "JA" => "Jalisco", "EM" => "México State", "MI" => "Michoacán", "MO" => "Morelos", "NA" => "Nayarit", "NL" => "Nuevo León",
		"OA" => "Oaxaca", "PU" => "Puebla", "QE" => "Querétaro", "QR" => "Quintana Roo", "SI" => "Sinaloa", "SL" => "San Luis Potosí", "SO" => "Sonora",
		"TB" => "Tabasco", "TL" => "Tlaxcala", "TM" => "Tamaulipas", "VE" => "Veracruz", "YU" => "Yucatán", "ZA" => "Zacatecas",
	);
	//USA
	$stateCodeToRegex['US'] = array(
		'AL' => 'al|alabama', 'AK' => 'AK|alaska', 'AZ' => 'AZ|arizona', 'AR' => 'AR|arkansas', 'CA' => 'CA|california', 'CO' => 'CO|colorado',
		'CT' => 'CT|connecticut', 'DE' => 'DE|delaware', 'FL' => 'FL|florida', 'GA' => 'GA|georgia', 'HI' => 'HI|hawaii', 'ID' => 'ID|idaho', 'IL' => 'IL|illinois',
		'IN' => 'IN|indiana', 'IA' => 'IA|iowa', 'KS' => 'KS|kansas', 'KY' => 'KY|kentucky', 'LA' => 'LA|louisiana', 'ME' => 'ME|maine', 'MD' => 'MD|maryland',
		'MA' => 'MA|massachusetts', 'MI' => 'MI|michigan', 'MN' => 'MN|minnesota', 'MS' => 'MS|mississippi', 'MO' => 'MO|missouri', 'MT' => 'MT|montana', 'NE' => 'NE|nebraska',
		'NV' => 'NV|nevada', 'NH' => 'NH|(new )?hampshire', 'NJ' => 'NJ|(new )?jersey', 'NM' => 'NM|(new )?mexico', 'NY' => 'NY|(new )?york', 'NC' => 'NC|north carolina',
		'ND' => 'ND|north dakota', 'OH' => 'OH|ohio', 'OK' => 'OK|oklahoma', 'OR' => 'OR|oregon', 'PA' => 'PA|pennsylvania', 'RI' => 'RI|rhode island', 'SC' => 'SC|south carolina',
		'SD' => 'SD|south dakota', 'TN' => 'TN|tennessee', 'TX' => 'TX|texas', 'UT' => 'UT|utah', 'VT' => 'VT|vermont', 'VA' => 'VA|virginia', 'WA' => 'WA|washington',
		'WV' => 'WV|west virginia', 'WI' => 'WI|wisconsin', 'WY' => 'WY|wyoming', 'DC' => 'DC|(district (of )?)?columbia'
	);
	$stateCodeToState['US'] = array(
		'AL' => 'Alabama', 'AK' => 'Alaska', 'AZ' => 'Arizona', 'AR' => 'Arkansas', 'CA' => 'California', 'CO' => 'Colorado', 'CT' => 'Connecticut',
		'DE' => 'Delaware', 'FL' => 'Florida', 'GA' => 'Georgia', 'HI' => 'Hawaii', 'ID' => 'Idaho', 'IL' => 'Illinois', 'IN' => 'Indiana', 'IA' => 'Iowa', 'KS' => 'Kansas',
		'KY' => 'Kentucky', 'LA' => 'Louisiana', 'ME' => 'Maine', 'MD' => 'Maryland', 'MA' => 'Massachusetts', 'MI' => 'Michigan', 'MN' => 'Minnesota', 'MS' => 'Mississippi',
		'MO' => 'Missouri', 'MT' => 'Montana', 'NE' => 'Nebraska', 'NV' => 'Nevada', 'NH' => 'New Hampshire', 'NJ' => 'New Jersey', 'NM' => 'New Mexico', 'NY' => 'New York',
		'NC' => 'North Carolina', 'ND' => 'North Dakota', 'OH' => 'Ohio', 'OK' => 'Oklahoma', 'OR' => 'Oregon', 'PA' => 'Pennsylvania', 'RI' => 'Rhode Island',
		'SC' => 'South Carolina', 'SD' => 'South Dakota', 'TN' => 'Tennessee', 'TX' => 'Texas', 'UT' => 'Utah', 'VT' => 'Vermont', 'VA' => 'Virginia', 'WA' => 'Washington',
		'WV' => 'West Virginia', 'WI' => 'Wisconsin', 'WY' => 'Wyoming', 'DC' => 'District of Columbia'
	);
}
